package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.PayMoneyLogMapper;
import com.ruoyi.system.domain.PayMoneyLog;
import com.ruoyi.system.service.IPayMoneyLogService;

/**
 * 支付记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class PayMoneyLogServiceImpl implements IPayMoneyLogService 
{
    @Autowired
    private PayMoneyLogMapper payMoneyLogMapper;

    /**
     * 查询支付记录
     * 
     * @param id 支付记录主键
     * @return 支付记录
     */
    @Override
    public PayMoneyLog selectPayMoneyLogById(Long id)
    {
        return payMoneyLogMapper.selectPayMoneyLogById(id);
    }

    /**
     * 查询支付记录列表
     * 
     * @param payMoneyLog 支付记录
     * @return 支付记录
     */
    @Override
    public List<PayMoneyLog> selectPayMoneyLogList(PayMoneyLog payMoneyLog)
    {
        return payMoneyLogMapper.selectPayMoneyLogList(payMoneyLog);
    }

    /**
     * 新增支付记录
     * 
     * @param payMoneyLog 支付记录
     * @return 结果
     */
    @Override
    public int insertPayMoneyLog(PayMoneyLog payMoneyLog)
    {
        return payMoneyLogMapper.insertPayMoneyLog(payMoneyLog);
    }

    /**
     * 修改支付记录
     * 
     * @param payMoneyLog 支付记录
     * @return 结果
     */
    @Override
    public int updatePayMoneyLog(PayMoneyLog payMoneyLog)
    {
        return payMoneyLogMapper.updatePayMoneyLog(payMoneyLog);
    }

    /**
     * 批量删除支付记录
     * 
     * @param ids 需要删除的支付记录主键
     * @return 结果
     */
    @Override
    public int deletePayMoneyLogByIds(Long[] ids)
    {
        return payMoneyLogMapper.deletePayMoneyLogByIds(ids);
    }

    /**
     * 删除支付记录信息
     * 
     * @param id 支付记录主键
     * @return 结果
     */
    @Override
    public int deletePayMoneyLogById(Long id)
    {
        return payMoneyLogMapper.deletePayMoneyLogById(id);
    }
}
