package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.Order;
import com.ruoyi.system.domain.Users;
import com.ruoyi.system.service.IOrderService;
import com.ruoyi.system.service.IUsersService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PayMoneyLog;
import com.ruoyi.system.service.IPayMoneyLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 支付记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/PayMoneyLog")
public class PayMoneyLogController extends BaseController
{
    @Autowired
    private IPayMoneyLogService payMoneyLogService;

    @Autowired
    private IUsersService   usersService;

    @Autowired
    private IOrderService orderService;

    /**
     * 查询支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(PayMoneyLog payMoneyLog)
    {
        startPage();
        List<PayMoneyLog> list = payMoneyLogService.selectPayMoneyLogList(payMoneyLog);
        for (PayMoneyLog payMoneyLogdata : list){
            Users users=usersService.selectUsersById(payMoneyLogdata.getUid());
            if (users!=null){
                payMoneyLogdata.setUname(users.getName());
            }
            Order   order=orderService.selectOrderById(payMoneyLogdata.getOid());
            if(order!=null){
                payMoneyLogdata.setOcode(order.getOrderId());

            }

        }
        return getDataTable(list);
    }
    /**
     * 获取项目报价--工艺分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:query')")
    @GetMapping(value = "/getUsersDataList")
    public AjaxResult getUsersDataList()
    {
        return success(usersService.selectUsersList(new Users()));
    }
    /**
     * 导出支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:export')")
    @Log(title = "支付记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PayMoneyLog payMoneyLog)
    {
        List<PayMoneyLog> list = payMoneyLogService.selectPayMoneyLogList(payMoneyLog);
        ExcelUtil<PayMoneyLog> util = new ExcelUtil<PayMoneyLog>(PayMoneyLog.class);
        util.exportExcel(response, list, "支付记录数据");
    }

    /**
     * 获取支付记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(payMoneyLogService.selectPayMoneyLogById(id));
    }

    /**
     * 新增支付记录
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:add')")
    @Log(title = "支付记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PayMoneyLog payMoneyLog)
    {
        return toAjax(payMoneyLogService.insertPayMoneyLog(payMoneyLog));
    }

    /**
     * 修改支付记录
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:edit')")
    @Log(title = "支付记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PayMoneyLog payMoneyLog)
    {
        return toAjax(payMoneyLogService.updatePayMoneyLog(payMoneyLog));
    }

    /**
     * 删除支付记录
     */
    @PreAuthorize("@ss.hasPermi('system:PayMoneyLog:remove')")
    @Log(title = "支付记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(payMoneyLogService.deletePayMoneyLogByIds(ids));
    }
}
